@@ -170,6 +170,27 @@ static void benchmarkHashFunctionTime (void)
  * seeds)
  */
 
+static void benchmarkMappingCheckOpmphm (Opmphm * opmphm, OpmphmGraph * graph, size_t n, OpmphmInit * init, size_t mappings,
+					 size_t maxMappings)
+{
+	if (n < 5 && mappings != maxMappings)
+	{
+		// assign
+		if (opmphmAssignment (opmphm, graph, n, 1))
+		{
+			printExit ("check assignment failed");
+		}
+		for (size_t i = 0; i < n; ++i)
+		{
+			if (i != opmphmLookup (opmphm, n, init->getName (init->data[i])))
+			{
+				printExit ("check assignment failed");
+			}
+		}
+		opmphmClear (opmphm);
+	}
+}
+
 static void benchmarkMapping (void)
 {
 	size_t rUniPar = 3;
@@ -310,23 +331,9 @@ static void benchmarkMapping (void)
 						{
 							printExit ("benchmarkSeedRangeMappingCount: mappings out of range");
 						}
-						// check assignment
-						if (nI < 5 && mappings != maxMappings)
-						{
-							// assign
-							if (opmphmAssignment (opmphms[threadI], graphs[threadI], n[nI], 1))
-							{
-								printExit ("check assignment failed");
-							}
-							for (size_t i = 0; i < n[nI]; ++i)
-							{
-								if (i != opmphmLookup (opmphms[threadI], init.getName (init.data[i])))
-								{
-									printExit ("check assignment failed");
-								}
-							}
-							opmphmClear (opmphms[threadI]);
-						}
+						// check opmphm
+						benchmarkMappingCheckOpmphm (opmphms[threadI], graphs[threadI], n[nI], &init, mappings,
+									     maxMappings);
 						// save result
 						// shift, because 0 not used
 						--mappings;
@@ -449,8 +456,12 @@ static void benchmarkMappingOpt (void)
 {
 	// create the n array
 	const size_t nCount = 132;
+	size_t * n = elektraMalloc (nCount * sizeof (size_t));
+	if (!n)
+	{
+		printExit ("malloc");
+	}
 	size_t controlCount = 0;
-	size_t n[nCount];
 	for (size_t i = 2; i <= 38; ++i)
 	{
 		n[controlCount] = i;
@@ -616,7 +627,7 @@ static void benchmarkMappingOpt (void)
 						}
 						for (size_t i = 0; i < n[nI]; ++i)
 						{
-							if (i != opmphmLookup (opmphms[threadI], init.getName (init.data[i])))
+							if (i != opmphmLookup (opmphms[threadI], n[nI], init.getName (init.data[i])))
 							{
 								printExit ("check assignment failed");
 							}
@@ -706,6 +717,7 @@ static void benchmarkMappingOpt (void)
 	{
 		ksDel (keySetsCache[i]);
 	}
+	elektraFree (n);
 	elektraFree (keySetsCache);
 	fclose (out);
 	elektraFree (keySetShapes);
@@ -734,7 +746,11 @@ static void benchmarkMappingAllSeeds (void)
 {
 	// create the n array
 	const size_t nCount = 7;
-	size_t n[nCount];
+	size_t * n = elektraMalloc (nCount * sizeof (size_t));
+	if (!n)
+	{
+		printExit ("malloc");
+	}
 	n[0] = 9;
 	n[1] = 29;
 	n[2] = 49;
@@ -837,7 +853,7 @@ static void benchmarkMappingAllSeeds (void)
 			OpmphmInit init;
 			init.getName = elektraGetString;
 			init.data = (void **)(ks->array);
-// OPMPHM
+			// OPMPHM
 
 #ifdef USE_OPENMP
 			threadI = omp_get_thread_num ();
@@ -953,6 +969,7 @@ static void benchmarkMappingAllSeeds (void)
 	{
 		ksDel (keySetsCache[i]);
 	}
+	elektraFree (n);
 	elektraFree (keySetsCache);
 	fclose (out);
 	elektraFree (keySetShapes);
@@ -1003,7 +1020,11 @@ int main (int argc, char ** argv)
 {
 	// define all benchmarks
 	const size_t benchmarksCount = 5;
-	Benchmark benchmarks[benchmarksCount];
+	Benchmark * benchmarks = elektraMalloc (benchmarksCount * sizeof (Benchmark));
+	if (!benchmarks)
+	{
+		printExit ("malloc");
+	}
 	// hashfunctiontime
 	char * benchmarkNameHashFunctionTime = "hashfunctiontime";
 	benchmarks[0].name = benchmarkNameHashFunctionTime;
@@ -1034,6 +1055,7 @@ int main (int argc, char ** argv)
 		{
 			fprintf (stderr, "* %s\n", benchmarks[i].name);
 		}
+		elektraFree (benchmarks);
 		return EXIT_FAILURE;
 	}
 	for (size_t i = 0; i < benchmarksCount; ++i)
@@ -1041,6 +1063,7 @@ int main (int argc, char ** argv)
 		if (!strncmp (benchmarks[i].name, argv[1], strlen (argv[1])))
 		{
 			benchmarks[i].benchmarkF ();
+			elektraFree (benchmarks);
 			return EXIT_SUCCESS;
 		}
 	}
@@ -1050,6 +1073,7 @@ int main (int argc, char ** argv)
 	{
 		fprintf (stderr, "* %s\n", benchmarks[i].name);
 	}
+	elektraFree (benchmarks);
 	return EXIT_FAILURE;
 }
 
