@@ -3,13 +3,13 @@
  *
  * @brief
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
 #include <kdb.h>
 #include <stdio.h>
 
-int main ()
+int main (void)
 {
 	KeySet * ks = ksNew (0, KS_END);
 	Key * key = 0;
