@@ -11,7 +11,7 @@ extern "C" {
 
 typedef struct _ElektraInvokeHandle ElektraInvokeHandle;
 
-ElektraInvokeHandle * elektraInvokeOpen (const char *, KeySet * config);
+ElektraInvokeHandle * elektraInvokeOpen (const char *, KeySet * config, Key * errorKey);
 ElektraInvokeHandle * elektraInvokeInitialize (const char *);
 
 const void * elektraInvokeGetFunction (ElektraInvokeHandle *, const char *);
@@ -24,7 +24,7 @@ KeySet * elektraInvokeGetExports (ElektraInvokeHandle *);
 
 int elektraInvoke2Args (ElektraInvokeHandle *, const char *, KeySet * ks, Key * k);
 
-void elektraInvokeClose (ElektraInvokeHandle *);
+void elektraInvokeClose (ElektraInvokeHandle *, Key * errorKey);
 
 
 #ifdef __cplusplus
