@@ -8,9 +8,11 @@
 
 #include "kdbrand.h"
 #include <kdbassert.h>
+#include <time.h>
 
 /**
- * Non cryptographic pseudo random number generator
+ * @brief Non cryptographic pseudo random number generator
+ *
  * By Ray Gardner
  * www8.cs.umu.se/~isak/snippets/rg_rand.c
  *
@@ -51,11 +53,31 @@ void elektraRand (int32_t * seed)
 	*seed = (int32_t)lo;
 }
 
+/**
+ * @brief Random initial seed generator
+ *
+ * Generates a random initial seed for the `elektraRand (...)` function.
+ * Two invocations in the same second return the same random initial seed, due to
+ * the usage of `time (0)`.
+ *
+ * @retval random initial seed
+ *
+ */
 int32_t elektraRandGetInitSeed (void)
 {
+	int32_t initSeed = time (0);
+	// ELEKTRARANDMAX is limit
+	if (initSeed >= ELEKTRARANDMAX)
+	{
+		initSeed = initSeed % ELEKTRARANDMAX;
+	}
+	// 0 not accepted by elektraRand
+	if (!initSeed)
+	{
+		initSeed = 1;
+	}
 #ifdef KDBRAND_BENCHMARK
-	return elektraRandBenchmarkInitSeed;
-#else
-	return 1;
+	initSeed = elektraRandBenchmarkInitSeed;
 #endif
+	return initSeed;
 }
