@@ -126,10 +126,11 @@ bool Plugins::checkPlacement (Plugin & plugin, std::string which)
 		std::ostringstream os;
 		os << "Too many plugins!\n"
 		      "The plugin "
-		   << plugin.name () << " can't be positioned to position " << which << " anymore.\n"
-											"Try to reduce the number of plugins!\n"
-											"\n"
-											"Failed because of stack overflow: cant place to "
+		   << plugin.name () << " can't be positioned at position " << which
+		   << " anymore.\n"
+		      "Try to reduce the number of plugins!\n"
+		      "\n"
+		      "Failed because of stack overflow: cant place to "
 		   << revPostGet << " because " << placementInfo["postgetstorage"].current << " is larger (this slot is in use)." << endl;
 		throw TooManyPlugins (os.str ());
 	}
@@ -139,10 +140,11 @@ bool Plugins::checkPlacement (Plugin & plugin, std::string which)
 		std::ostringstream os;
 		os << "Too many plugins!\n"
 		      "The plugin "
-		   << plugin.name () << " can't be positioned to position " << which << " anymore.\n"
-											"Try to reduce the number of plugins!\n"
-											"\n"
-											"Failed because "
+		   << plugin.name () << " can't be positioned at position " << which
+		   << " anymore.\n"
+		      "Try to reduce the number of plugins!\n"
+		      "\n"
+		      "Failed because "
 		   << which << " with " << placementInfo[which].current << " is larger than " << placementInfo[which].max << endl;
 		throw TooManyPlugins (os.str ());
 	}
@@ -214,7 +216,7 @@ void Plugins::checkResolver (Plugin & plugin)
 
 
 /** Check ordering of plugins.
-  */
+ */
 void Plugins::checkOrdering (Plugin & plugin)
 {
 	std::string order;
@@ -234,7 +236,7 @@ void Plugins::checkOrdering (Plugin & plugin)
 }
 
 /** Check conflicts of plugins.
-  */
+ */
 void Plugins::checkConflicts (Plugin & plugin)
 {
 	{
