@@ -133,7 +133,7 @@ static int decode (Key * key, Key * parent, bool metaMode)
  */
 static int encode (Key * key, Key * parent, bool metaMode)
 {
-	if (!keyIsBinary (key)) return 0;
+	if (!keyIsBinary (key) || (keyGetValueSize (key) == 0 && metaMode)) return 0;
 
 	char * base64 = PLUGIN_FUNCTION (base64Encode) (keyValue (key), (size_t)keyGetValueSize (key));
 	if (!base64)
