@@ -3,7 +3,7 @@
  *
  * @brief Source for cachefilter plugin
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  *
  */
 
@@ -13,6 +13,8 @@
 #include <kdberrors.h>
 #include <kdbhelper.h>
 
+#include <kdblogger.h>
+
 
 int elektraCachefilterGet (Plugin * handle, KeySet * returned, Key * parentKey)
 {
@@ -32,47 +34,63 @@ int elektraCachefilterGet (Plugin * handle, KeySet * returned, Key * parentKey)
 		return 1; // success
 	}
 
+	ELEKTRA_LOG ("cachefilter get %s start %zd", keyName (parentKey), ksGetSize (returned));
 	// initialize working KeySets
 	KeySet * toBeCached = 0;
-	KeySet * temp = 0;
 
 	// get old cache data
-	void * cachedData = elektraPluginGetData (handle);
-	if (cachedData != NULL)
-	{
-		toBeCached = (KeySet *)cachedData;
-	}
-	else
+	void * cache = elektraPluginGetData (handle);
+	if (cache == NULL)
 	{
 		toBeCached = ksNew (ksGetSize (returned), KS_END);
 	}
+	else
+	{
+		toBeCached = (KeySet *)cache;
+	}
 
-	// filter keys that need to be cached
-	temp = ksCut (returned, parentKey);
+	// first ensure the cache is up to date with the
+	// freshly requested keys
 	ksAppend (toBeCached, returned);
-	ksClear (returned);
-	ksAppend (returned, temp);
-	ksDel (temp);
 
-	// cache the filtered keys
+	// then ensure to return only the requested keys
+	// (matching parentKey)
+	ksClear (returned);
+	KeySet * requestedKeys = ksCut (toBeCached, parentKey);
+	ksAppend (returned, requestedKeys);
+	ksDel (requestedKeys);
+
+	// and also keep the returned keys in cache as well
+	// this is necessary for successive kdbGet() calls
+	ksAppend (toBeCached, returned);
+
+	// point the plugin data to the cached keyset
 	elektraPluginSetData (handle, toBeCached);
+	ELEKTRA_LOG ("cachefilter get %s end %zd", keyName (parentKey), ksGetSize (returned));
 
 	return 1; // success
 }
 
-int elektraCachefilterSet (Plugin * handle, KeySet * returned, Key * parentKey ELEKTRA_UNUSED)
+int elektraCachefilterSet (Plugin * handle, KeySet * returned, Key * parentKey)
 {
+	ELEKTRA_LOG ("cachefilter set %s begin %zd", keyName (parentKey), ksGetSize (returned));
 	// get cached keys
-	KeySet * cachedKeys = (KeySet *)elektraPluginGetData (handle);
-	if (cachedKeys == NULL)
+	void * cache = elektraPluginGetData (handle);
+	if (cache == NULL)
 	{
-		ELEKTRA_SET_ERROR_SET (parentKey);
+		ELEKTRA_SET_ERROR (107, parentKey, "Cache was not initialized.");
 		return -1; // did not call kdbGet() before and therefore
 			   // also no elektraCachefilterGet()
 	}
 
-	// mix all keys that need to be stored together
+	KeySet * cachedKeys = (KeySet *)cache;
+
+	// first remove all keys from the cache that match the parentKey
+	// but are not in the returned keyset anymore (deleted keys)
+	ksDel (ksCut (cachedKeys, parentKey));
+	ksAppend (cachedKeys, returned);
 	ksAppend (returned, cachedKeys);
+	ELEKTRA_LOG ("cachefilter set %s end %zd", keyName (parentKey), ksGetSize (returned));
 
 	return 1; // success
 }
