@@ -81,10 +81,10 @@ typedef struct
 /* -- Macros ---------------------------------------------------------------------------------------------------------------------------- */
 
 #define LOG_PARSE(data, message, ...)                                                                                                      \
-	ELEKTRA_LOG_DEBUG ("%s:%lu:%lu: " message, strrchr (keyString (data->parentKey), '/') + 1, data->line, data->column, __VA_ARGS__);
+	ELEKTRA_LOG_DEBUG ("%s:%zu:%zu: " message, strrchr (keyString (data->parentKey), '/') + 1, data->line, data->column, __VA_ARGS__);
 
 #define SET_ERROR_PARSE(data, message, ...)                                                                                                \
-	ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_PARSE, data->parentKey, "%s:%lu:%lu: " message, keyString (data->parentKey), data->line,         \
+	ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_PARSE, data->parentKey, "%s:%zu:%zu: " message, keyString (data->parentKey), data->line,         \
 			    data->column, __VA_ARGS__);
 
 #define RET_NOK(function)                                                                                                                  \
@@ -659,17 +659,17 @@ static int parseFile (KeySet * returned ELEKTRA_UNUSED, Key * parentKey)
 
 	ELEKTRA_LOG ("Read configuration data");
 
-	parserType * parser = &(parserType){.status = OK,
-					    .line = 1,
-					    .column = 1,
-					    .file = NULL,
-					    .match = NULL,
-					    .bufferBase = NULL,
-					    .buffer = NULL,
-					    .bufferCharsAvailable = 0,
-					    .parentKey = parentKey,
-					    .keySet = returned,
-					    .errorNumber = errno };
+	parserType * parser = &(parserType){ .status = OK,
+					     .line = 1,
+					     .column = 1,
+					     .file = NULL,
+					     .match = NULL,
+					     .bufferBase = NULL,
+					     .buffer = NULL,
+					     .bufferCharsAvailable = 0,
+					     .parentKey = parentKey,
+					     .keySet = returned,
+					     .errorNumber = errno };
 
 	if (openFile (parser)->status == OK) pairs (parser);
 	cleanup (parser);
