@@ -82,7 +82,7 @@ typedef struct
 static int elektraResolveFilename (Key * parentKey, ElektraResolveTempfile tmpFile)
 {
 	int rc = 0;
-	void * handle = elektraInvokeOpen ("resolver", 0);
+	void * handle = elektraInvokeOpen ("resolver", 0, 0);
 	if (!handle)
 	{
 		rc = -1;
@@ -121,7 +121,7 @@ static int elektraResolveFilename (Key * parentKey, ElektraResolveTempfile tmpFi
 	}
 
 RESOLVE_FAILED:
-	elektraInvokeClose (handle);
+	elektraInvokeClose (handle, 0);
 	return rc;
 }
 
