@@ -3,7 +3,7 @@
  *
  * @brief filter plugin providing cryptographic operations
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  *
  */
 
@@ -17,9 +17,11 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <gpg.h>
+#include <libgen.h> // provides basename()
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
 
@@ -37,8 +39,9 @@ enum FcryptGetState
 struct _fcryptState
 {
 	enum FcryptGetState getState;
-	struct stat parentStat;
-	int parentStatOk;
+	int tmpFileFd;
+	char * tmpFilePath;
+	char * originalFilePath;
 };
 typedef struct _fcryptState fcryptState;
 
@@ -46,19 +49,48 @@ typedef struct _fcryptState fcryptState;
 
 /**
  * @brief Allocates a new string holding the name of the temporary file.
+ * This method makes use of the "fcrypt/tmpdir" plugin configuration option.
+ * @param conf holds the plugin configuration
  * @param file holds the path to the original file
  * @param fd will hold the file descriptor to the temporary file in case of success
  * @returns an allocated string holding the name of the encrypted file. Must be freed by the caller.
  */
-static char * getTemporaryFileName (const char * file, int * fd)
+static char * getTemporaryFileName (KeySet * conf, const char * file, int * fd)
 {
+	// read the temporary directory to use from the plugin configuration
+	const char * tmpDir = ELEKTRA_FCRYPT_DEFAULT_TMPDIR;
+	Key * k = ksLookupByName (conf, ELEKTRA_FCRYPT_CONFIG_TMPDIR, 0);
+	if (k)
+	{
+		tmpDir = keyString (k);
+	}
+
+	// extract the file name (base name) from the path
+	char * fileDup = strdup (file);
+	if (!fileDup) goto error;
+	const char * baseName = basename (fileDup);
+
+	// + 1 to add an additional '/' as path separator
 	// + 1 to reserve space for the NULL terminator
-	const size_t newFileAllocated = strlen (file) + strlen (ELEKTRA_FCRYPT_TMP_FILE_SUFFIX) + 1;
+	// ----------------------------------------------
+	// + 2 characters in total
+	const size_t newFileAllocated = strlen (tmpDir) + strlen (baseName) + strlen (ELEKTRA_FCRYPT_TMP_FILE_SUFFIX) + 2;
 	char * newFile = elektraMalloc (newFileAllocated);
-	if (!newFile) return NULL;
-	snprintf (newFile, newFileAllocated, "%s" ELEKTRA_FCRYPT_TMP_FILE_SUFFIX, file);
+	if (!newFile) goto error;
+	snprintf (newFile, newFileAllocated, "%s/%s" ELEKTRA_FCRYPT_TMP_FILE_SUFFIX, tmpDir, baseName);
 	*fd = mkstemp (newFile);
+	if (*fd < 0)
+	{
+		elektraFree (newFile);
+		goto error;
+	}
+
+	elektraFree (fileDup);
 	return newFile;
+
+error:
+	elektraFree (fileDup);
+	return NULL;
 }
 
 /**
@@ -81,15 +113,21 @@ static int shredTemporaryFile (int fd, Key * errorKey)
 
 	if (lseek (fd, 0, SEEK_SET))
 	{
-		ELEKTRA_SET_ERROR (ELEKTRA_ERROR_FCRYPT_TMP_FILE, errorKey, "Failed to overwrite the temporary file.");
-		return -1;
+		goto error;
 	}
 
 	for (off_t i = 0; i < tmpStat.st_size; i += sizeof (buffer))
 	{
-		write (fd, buffer, sizeof (buffer));
+		if (write (fd, buffer, sizeof (buffer)) != sizeof (buffer))
+		{
+			goto error;
+		}
 	}
 	return 1;
+
+error:
+	ELEKTRA_SET_ERROR (ELEKTRA_ERROR_FCRYPT_TMP_FILE, errorKey, "Failed to overwrite the temporary file.");
+	return -1;
 }
 
 /**
@@ -108,16 +146,34 @@ static int inTestMode (KeySet * conf)
 	return 0;
 }
 
+/**
+ * @brief lookup if the text mode is disabled in the plugin config.
+ * It is enabled per default.
+ * @param conf KeySet holding the plugin configuration.
+ * @retval 0 text mode is not enabled
+ * @retval 1 text mode is enabled
+ */
+static int inTextMode (KeySet * conf)
+{
+	Key * k = ksLookupByName (conf, ELEKTRA_FCRYPT_CONFIG_TEXTMODE, 0);
+	if (k && !strcmp (keyString (k), "0"))
+	{
+		return 0;
+	}
+	return 1;
+}
+
 /**
  * @brief Read number of total GPG recipient keys from the plugin configuration.
  * @param config holds the plugin configuration
+ * @param keyName holds the name of the root key to look up
  * @returns the number of GPG recipient keys.
  */
-static size_t getRecipientCount (KeySet * config)
+static size_t getRecipientCount (KeySet * config, const char * keyName)
 {
 	Key * k;
 	size_t recipientCount = 0;
-	Key * root = ksLookupByName (config, ELEKTRA_CRYPTO_PARAM_GPG_KEY, 0);
+	Key * root = ksLookupByName (config, keyName, 0);
 
 	if (!root) return 0;
 
@@ -138,54 +194,6 @@ static size_t getRecipientCount (KeySet * config)
 	return recipientCount;
 }
 
-/**
- * @brief Determines mtime for the file given by parentKey.
- * @param parentKey holds the path to the file as string value. Is also used for storing warnings.
- * @param fileStat will hold the mtime on success.
- * @retval 1 on success
- * @retval 0 on failure. In this case a warning is appended to parentKey.
- */
-static int fcryptSaveMtime (Key * parentKey, struct stat * fileStat)
-{
-	if (access (keyString (parentKey), F_OK))
-	{
-		// return failure, so no timestamp is restored later on
-		return 0;
-	}
-
-	if (stat (keyString (parentKey), fileStat) == -1)
-	{
-		ELEKTRA_ADD_WARNINGF (29, parentKey, "Failed to read file stats of %s", keyString (parentKey));
-		return 0;
-	}
-	return 1;
-}
-
-/**
- * @brief Sets mtime (defined by fileStat) to the file given by parentKey.
- * @param parentKey  holds the path to the file as string value. Is also used for storing warnings.
- * @param fileStat holds the mtime to be set on the file.
- */
-static void fcryptRestoreMtime (Key * parentKey, struct stat * fileStat)
-{
-	struct timespec times[2];
-
-	// atime - not changing
-	times[0].tv_sec = UTIME_OMIT;
-	times[0].tv_nsec = UTIME_OMIT;
-
-	// mtime
-	times[1].tv_sec = ELEKTRA_STAT_SECONDS ((*fileStat));
-	times[1].tv_nsec = ELEKTRA_STAT_NANO_SECONDS ((*fileStat));
-
-	// restore mtime on parentKeyFd
-	// if (futimens (fileDescriptor, times))
-	if (utimensat (AT_FDCWD, keyString (parentKey), times, 0))
-	{
-		ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_FUTIMENS, parentKey, "Filename: %s", keyString (parentKey));
-	}
-}
-
 static int fcryptGpgCallAndCleanup (Key * parentKey, KeySet * pluginConfig, char ** argv, int argc, int tmpFileFd, char * tmpFile)
 {
 	int parentKeyFd = -1;
@@ -214,47 +222,69 @@ static int fcryptGpgCallAndCleanup (Key * parentKey, KeySet * pluginConfig, char
 	{
 		// if anything went wrong above the temporary file is shredded and removed
 		shredTemporaryFile (tmpFileFd, parentKey);
-		unlink (tmpFile);
+		if (unlink (tmpFile))
+		{
+			ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_UNLINK, parentKey, "Affected file: %s, error description: %s", tmpFile,
+					      strerror (errno));
+		}
 	}
 
-	if (parentKeyFd >= 0)
+	if (parentKeyFd >= 0 && close (parentKeyFd))
 	{
-		close (parentKeyFd);
+		ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
+	}
+	if (close (tmpFileFd))
+	{
+		ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
 	}
-	close (tmpFileFd);
 	elektraFree (tmpFile);
 	return result;
 }
 
 /**
- * @brief encrypt the file specified at parentKey
+ * @brief encrypt or sign the file specified at parentKey
  * @param pluginConfig holds the plugin configuration
- * @pararm parentKey holds the path to the file to be encrypted. Will hold an error description in case of failure.
+ * @param parentKey holds the path to the file to be encrypted. Will hold an error description in case of failure.
  * @retval 1 on success
  * @retval -1 on error, errorKey holds an error description
  */
 static int fcryptEncrypt (KeySet * pluginConfig, Key * parentKey)
 {
-	const size_t recipientCount = getRecipientCount (pluginConfig);
-	if (recipientCount == 0)
+	Key * k;
+	const size_t recipientCount = getRecipientCount (pluginConfig, ELEKTRA_RECIPIENT_KEY);
+	const size_t signatureCount = getRecipientCount (pluginConfig, ELEKTRA_SIGNATURE_KEY);
+
+	if (recipientCount == 0 && signatureCount == 0)
 	{
-		ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_CRYPTO_CONFIG_FAULT, parentKey,
-				    "Missing GPG key (specified as %s) in plugin configuration.", ELEKTRA_CRYPTO_PARAM_GPG_KEY);
+		ELEKTRA_SET_ERRORF (
+			ELEKTRA_ERROR_FCRYPT_OPERATION_MODE, parentKey,
+			"Missing GPG recipient key (specified as %s) or GPG signature key (specified as %s) in plugin configuration.",
+			ELEKTRA_RECIPIENT_KEY, ELEKTRA_SIGNATURE_KEY);
 		return -1;
 	}
 
-	const size_t testMode = inTestMode (pluginConfig);
 	int tmpFileFd = -1;
-
-	char * tmpFile = getTemporaryFileName (keyString (parentKey), &tmpFileFd);
+	char * tmpFile = getTemporaryFileName (pluginConfig, keyString (parentKey), &tmpFileFd);
 	if (!tmpFile)
 	{
 		ELEKTRA_SET_ERROR (87, parentKey, "Memory allocation failed");
 		return -1;
 	}
 
+	const size_t testMode = inTestMode (pluginConfig);
+	const size_t textMode = inTextMode (pluginConfig);
+
 	// prepare argument vector for gpg call
-	int argc = 8 + (2 * recipientCount) + (2 * testMode);
+	// 7 static arguments (magic number below) are:
+	//   1. path to the binary
+	//   2. --batch
+	//   3. -o
+	//   4. path to tmp file
+	//   5. yes
+	//   6. file to be encrypted
+	//   7. NULL terminator
+	int argc = 7 + (2 * recipientCount) + (2 * signatureCount) + (2 * testMode) + textMode + (recipientCount > 0 ? 1 : 0) +
+		   (signatureCount > 0 ? 1 : 0);
 	kdb_unsigned_short_t i = 0;
 	char * argv[argc];
 	argv[i++] = NULL;
@@ -264,26 +294,55 @@ static int fcryptEncrypt (KeySet * pluginConfig, Key * parentKey)
 	argv[i++] = "--yes"; // overwrite files if they exist
 
 	// add recipients
-	Key * root = ksLookupByName (pluginConfig, ELEKTRA_CRYPTO_PARAM_GPG_KEY, 0);
+	Key * gpgRecipientRoot = ksLookupByName (pluginConfig, ELEKTRA_RECIPIENT_KEY, 0);
 
 	// append root (gpg/key) as gpg recipient
-	if (root && strlen (keyString (root)) > 0)
+	if (gpgRecipientRoot && strlen (keyString (gpgRecipientRoot)) > 0)
 	{
 		argv[i++] = "-r";
 		// NOTE argv[] values will not be modified, so const can be discarded safely
-		argv[i++] = (char *)keyString (root);
+		argv[i++] = (char *)keyString (gpgRecipientRoot);
 	}
 
 	// append keys beneath root (crypto/key/#_) as gpg recipients
-	Key * k;
-	ksRewind (pluginConfig);
-	while ((k = ksNext (pluginConfig)) != 0)
+	if (gpgRecipientRoot)
 	{
-		if (keyIsBelow (k, root))
+		ksRewind (pluginConfig);
+		while ((k = ksNext (pluginConfig)) != 0)
 		{
-			argv[i++] = "-r";
-			// NOTE argv[] values will not be modified, so const can be discarded safely
-			argv[i++] = (char *)keyString (k);
+			if (keyIsBelow (k, gpgRecipientRoot))
+			{
+				argv[i++] = "-r";
+				// NOTE argv[] values will not be modified, so const can be discarded safely
+				argv[i++] = (char *)keyString (k);
+			}
+		}
+	}
+
+
+	// add signature keys
+	Key * gpgSignatureRoot = ksLookupByName (pluginConfig, ELEKTRA_SIGNATURE_KEY, 0);
+
+	// append root signature key
+	if (gpgSignatureRoot && strlen (keyString (gpgSignatureRoot)) > 0)
+	{
+		argv[i++] = "-u";
+		// NOTE argv[] values will not be modified, so const can be discarded safely
+		argv[i++] = (char *)keyString (gpgSignatureRoot);
+	}
+
+	// append keys beneath root (fcrypt/sign/#_) as gpg signature keys
+	if (gpgSignatureRoot)
+	{
+		ksRewind (pluginConfig);
+		while ((k = ksNext (pluginConfig)) != 0)
+		{
+			if (keyIsBelow (k, gpgSignatureRoot))
+			{
+				argv[i++] = "-u";
+				// NOTE argv[] values will not be modified, so const can be discarded safely
+				argv[i++] = (char *)keyString (k);
+			}
 		}
 	}
 
@@ -294,8 +353,33 @@ static int fcryptEncrypt (KeySet * pluginConfig, Key * parentKey)
 		argv[i++] = "always";
 	}
 
+	// ASCII armor in text mode
+	if (textMode)
+	{
+		argv[i++] = "--armor";
+	}
+
 	// prepare rest of the argument vector
-	argv[i++] = "-e";
+	if (recipientCount > 0)
+	{
+		// encrypt the file
+		argv[i++] = "-e";
+	}
+
+	if (signatureCount > 0)
+	{
+		if (textMode && recipientCount == 0)
+		{
+			// clear-sign the file
+			argv[i++] = "--clearsign";
+		}
+		else
+		{
+			// sign the file
+			argv[i++] = "-s";
+		}
+	}
+
 	argv[i++] = (char *)keyString (parentKey);
 	argv[i++] = NULL;
 
@@ -309,14 +393,15 @@ static int fcryptEncrypt (KeySet * pluginConfig, Key * parentKey)
 /**
  * @brief decrypt the file specified at parentKey
  * @param pluginConfig holds the plugin configuration
- * @pararm parentKey holds the path to the file to be encrypted. Will hold an error description in case of failure.
+ * @param parentKey holds the path to the file to be encrypted. Will hold an error description in case of failure.
+ * @param state holds the plugin state
  * @retval 1 on success
  * @retval -1 on error, errorKey holds an error description
  */
-static int fcryptDecrypt (KeySet * pluginConfig, Key * parentKey)
+static int fcryptDecrypt (KeySet * pluginConfig, Key * parentKey, fcryptState * state)
 {
 	int tmpFileFd = -1;
-	char * tmpFile = getTemporaryFileName (keyString (parentKey), &tmpFileFd);
+	char * tmpFile = getTemporaryFileName (pluginConfig, keyString (parentKey), &tmpFileFd);
 	if (!tmpFile)
 	{
 		ELEKTRA_SET_ERROR (87, parentKey, "Memory allocation failed");
@@ -324,6 +409,17 @@ static int fcryptDecrypt (KeySet * pluginConfig, Key * parentKey)
 	}
 
 	const size_t testMode = inTestMode (pluginConfig);
+
+	// prepare argument vector for gpg call
+	// 8 static arguments (magic number below) are:
+	//   1. path to the binary
+	//   2. --batch
+	//   3. -o
+	//   4. path to tmp file
+	//   5. yes
+	//   6. -d
+	//   7. file to be encrypted
+	//   8. NULL terminator
 	int argc = 8 + (2 * testMode);
 	char * argv[argc];
 	int i = 0;
@@ -333,7 +429,7 @@ static int fcryptDecrypt (KeySet * pluginConfig, Key * parentKey)
 	argv[i++] = "--yes";
 
 	// if we are in test mode we add the trust model
-	if (inTestMode (pluginConfig))
+	if (testMode)
 	{
 		argv[i++] = "--trust-model";
 		argv[i++] = "always";
@@ -346,12 +442,32 @@ static int fcryptDecrypt (KeySet * pluginConfig, Key * parentKey)
 	argv[i++] = (char *)keyString (parentKey);
 	argv[i++] = NULL;
 
-
 	// NOTE the decryption process works like this:
 	// gpg2 --batch --yes -o tmpfile -d configFile
-	// mv tmpfile configFile
-
-	return fcryptGpgCallAndCleanup (parentKey, pluginConfig, argv, argc, tmpFileFd, tmpFile);
+	int result = CRYPTO_PLUGIN_FUNCTION (gpgCall) (pluginConfig, parentKey, NULL, argv, argc);
+	if (result == 1)
+	{
+		state->originalFilePath = strdup (keyString (parentKey));
+		state->tmpFilePath = tmpFile;
+		state->tmpFileFd = tmpFileFd;
+		keySetString (parentKey, tmpFile);
+	}
+	else
+	{
+		// if anything went wrong above the temporary file is shredded and removed
+		shredTemporaryFile (tmpFileFd, parentKey);
+		if (unlink (tmpFile))
+		{
+			ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_UNLINK, parentKey, "Affected file: %s, error description: %s", tmpFile,
+					      strerror (errno));
+		}
+		if (close (tmpFileFd))
+		{
+			ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
+		}
+		elektraFree (tmpFile);
+	}
+	return result;
 }
 
 /**
@@ -369,7 +485,9 @@ int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, open) (Plugin * handle, KeySet
 	}
 
 	s->getState = PREGETSTORAGE;
-	s->parentStatOk = 0;
+	s->tmpFileFd = -1;
+	s->tmpFilePath = NULL;
+	s->originalFilePath = NULL;
 
 	elektraPluginSetData (handle, s);
 	return 1;
@@ -385,6 +503,18 @@ int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, close) (Plugin * handle, KeySe
 	fcryptState * s = (fcryptState *)elektraPluginGetData (handle);
 	if (s)
 	{
+		if (s->tmpFileFd > 0 && close (s->tmpFileFd))
+		{
+			ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
+		}
+		if (s->tmpFilePath)
+		{
+			elektraFree (s->tmpFilePath);
+		}
+		if (s->originalFilePath)
+		{
+			elektraFree (s->originalFilePath);
+		}
 		elektraFree (s);
 		elektraPluginSetData (handle, NULL);
 	}
@@ -412,29 +542,49 @@ int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, get) (Plugin * handle, KeySet
 	// check plugin state
 	KeySet * pluginConfig = elektraPluginGetConfig (handle);
 	fcryptState * s = (fcryptState *)elektraPluginGetData (handle);
-
-	if (s && s->getState == POSTGETSTORAGE)
+	if (!s)
 	{
-		// encrypt if this is a postgetstorage call
-		int encryptResult = fcryptEncrypt (pluginConfig, parentKey);
+		ELEKTRA_SET_ERROR (ELEKTRA_ERROR_FCRYPT_STATE, parentKey, "No plugin state is available.");
+		return -1;
+	}
 
-		// restore "original" timestamp that has been saved in kdb get / pregetstorage
-		// NOTE if we do not restore the timestamp the resolver thinks the file has been changed externally.
-		if (encryptResult == 1 && s->parentStatOk)
+	if (s->getState == POSTGETSTORAGE)
+	{
+		// postgetstorage call will re-direct the parent key to the original encrypted/signed file
+		if (s->originalFilePath)
 		{
-			fcryptRestoreMtime (parentKey, &(s->parentStat));
+			keySetString (parentKey, s->originalFilePath);
 		}
-		return encryptResult;
+		else
+		{
+			ELEKTRA_SET_ERROR (ELEKTRA_ERROR_FCRYPT_STATE, parentKey, "The path to the original file is lost.");
+			// clean-up is performed by kdb close
+			return -1;
+		}
+
+		if (s->tmpFileFd > 0)
+		{
+			shredTemporaryFile (s->tmpFileFd, parentKey);
+			if (close (s->tmpFileFd))
+			{
+				ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
+			}
+			s->tmpFileFd = -1;
+			if (unlink (s->tmpFilePath))
+			{
+				ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_UNLINK, parentKey, "Affected file: %s, error description: %s",
+						      s->tmpFilePath, strerror (errno));
+			}
+			elektraFree (s->tmpFilePath);
+			s->tmpFilePath = NULL;
+		}
+		return 1;
 	}
 
 	// now this is a pregetstorage call
 	// next time treat the kdb get call as postgetstorage call to trigger encryption after the file has been read
 	s->getState = POSTGETSTORAGE;
-
-	// save timestamp of the file
-	s->parentStatOk = fcryptSaveMtime (parentKey, &(s->parentStat));
-
-	return fcryptDecrypt (pluginConfig, parentKey);
+	return fcryptDecrypt (pluginConfig, parentKey, s);
 }
 
 /**
@@ -450,7 +600,7 @@ int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, set) (Plugin * handle, KeySet
 
 	/* set all keys */
 	const char * configFile = keyString (parentKey);
-	if (!strcmp (configFile, "")) return 0; // no underlying config file
+	if (!strcmp (configFile, "")) return 1; // no underlying config file
 	int fd = open (configFile, O_RDWR);
 	if (fd == -1)
 	{
@@ -460,32 +610,21 @@ int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, set) (Plugin * handle, KeySet
 	if (fsync (fd) == -1)
 	{
 		ELEKTRA_SET_ERRORF (89, parentKey, "Could not fsync config file %s because %s", configFile, strerror (errno));
-		close (fd);
+		if (close (fd))
+		{
+			ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
+		}
 		return -1;
 	}
-	close (fd);
-
-	// restore "original" timestamp that has been saved in kdb get / pregetstorage
-	// NOTE if we do not restore the timestamp the resolver thinks the file has been changed externally.
-	fcryptState * s = (fcryptState *)elektraPluginGetData (handle);
-	if (s->parentStatOk)
+	if (close (fd))
 	{
-		fcryptRestoreMtime (parentKey, &(s->parentStat));
+		ELEKTRA_ADD_WARNINGF (ELEKTRA_WARNING_FCRYPT_CLOSE, parentKey, "%s", strerror (errno));
 	}
 	return 1;
 }
 
 /**
- * @brief Checks for the existence of the master password, that is used for encryption and decryption.
- *
- * If the master password can not be found it will be generated randomly.
- * Then it will be encrypted and stored in conf.
- *
- * If the master password can be found, it will be decrypted temporarily in order to verify its correctness.
- * conf will not be modified in this case.
- *
- * An error might occur during the password generation, encryption and decryption.
- * The error will be appended to errorKey.
+ * @brief Checks if at least one GPG recipient or at least one GPG signature key has been provided within the plugin configuration.
  *
  * @retval 0 no changes were made to the configuration
  * @retval 1 the master password has been appended to the configuration
@@ -493,10 +632,19 @@ int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, set) (Plugin * handle, KeySet
  */
 int ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME, checkconf) (Key * errorKey, KeySet * conf)
 {
-	if (getRecipientCount (conf) == 0)
+	const size_t recipientCount = getRecipientCount (conf, ELEKTRA_RECIPIENT_KEY);
+	const size_t signatureCount = getRecipientCount (conf, ELEKTRA_SIGNATURE_KEY);
+
+	if (recipientCount == 0 && signatureCount == 0)
 	{
-		ELEKTRA_SET_ERRORF (ELEKTRA_ERROR_CRYPTO_CONFIG_FAULT, errorKey,
-				    "Missing GPG key (specified as %s) in plugin configuration.", ELEKTRA_CRYPTO_PARAM_GPG_KEY);
+		char * errorDescription = CRYPTO_PLUGIN_FUNCTION (getMissingGpgKeyErrorText) (conf);
+		ELEKTRA_SET_ERROR (ELEKTRA_ERROR_FCRYPT_OPERATION_MODE, errorKey, errorDescription);
+		elektraFree (errorDescription);
+		return -1;
+	}
+	if (CRYPTO_PLUGIN_FUNCTION (gpgVerifyGpgKeysInConfig) (conf, errorKey) != 1)
+	{
+		// error has been set by CRYPTO_PLUGIN_FUNCTION (gpgVerifyGpgKeysInConfig)
 		return -1;
 	}
 	return 0;
