@@ -59,7 +59,7 @@ typedef struct
 static int elektraResolveFilename (Key * parentKey, ElektraResolveTempfile tmpFile)
 {
 	int rc = 0;
-	ElektraInvokeHandle * handle = elektraInvokeOpen ("resolver", 0);
+	ElektraInvokeHandle * handle = elektraInvokeOpen ("resolver", 0, 0);
 	if (!handle)
 	{
 		rc = -1;
@@ -98,7 +98,7 @@ static int elektraResolveFilename (Key * parentKey, ElektraResolveTempfile tmpFi
 	}
 
 RESOLVE_FAILED:
-	elektraInvokeClose (handle);
+	elektraInvokeClose (handle, 0);
 	return rc;
 }
 int elektraGitresolverCheckFile (const char * filename)
