@@ -1,5 +1,5 @@
 #include <git2.h>
-void main ()
+void main (void)
 {
 	git_libgit2_init ();
 	git_index_add_frombuffer (NULL, NULL, NULL, (size_t)NULL);
