@@ -106,7 +106,7 @@ static inline Codes rvToRc (int rc)
 static int elektraResolveFilename (Key * parentKey, ElektraResolveTempfile tmpFile)
 {
 	int rc = 0;
-	ElektraInvokeHandle * handle = elektraInvokeOpen ("resolver", 0);
+	ElektraInvokeHandle * handle = elektraInvokeOpen ("resolver", 0, 0);
 	if (!handle)
 	{
 		rc = -1;
@@ -145,7 +145,7 @@ static int elektraResolveFilename (Key * parentKey, ElektraResolveTempfile tmpFi
 	}
 
 RESOLVE_FAILED:
-	elektraInvokeClose (handle);
+	elektraInvokeClose (handle, 0);
 	return rc;
 }
 
