@@ -92,6 +92,13 @@ int ImportCommand::execute (Cmdline const & cl)
 
 	KeySet base = originalKeys.cut (root);
 	importedKeys = importedKeys.cut (root);
+	if (cl.withoutElektra)
+	{
+		KeySet baseCopy = base.dup ();
+		Key systemElektra ("system/elektra", KEY_END);
+		KeySet systemKeySet = baseCopy.cut (systemElektra);
+		importedKeys.append (systemKeySet);
+	}
 
 	ThreeWayMerge merger;
 	MergeHelper helper;
